# phipsair

A library and CLI for controlling Philips air purifiers via encrypted CoAP.

Forked from [betaboon's aioairctl](https://github.com/betaboon/aioairctrl) and [published on PyPI](https://pypi.org/project/phipsair/) for use from Home Assistant.

## Device Support

Currently tested with Philips AC2889/10 with firmware `1.0.7` and WiFi firmware `AWS_Philips_AIR@64.3`.

## License

[MIT](LICENSE)
